# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.28.1~67a145e',
    built_at='2026-03-17 14:01:19Z',
    sha='67a145e3946707c19b86c25b231f16bfebd1884f',
    branch='HEAD',
    tag='v4.28.1',
)
